@@ -439,6 +439,9 @@ class Completions:
                     "type": "json_schema",
                     "json_schema": type_to_response_format_param(response_format),
                 }
+            if isinstance(tools, Tools):
+                tools = tools.get_tool_definitions()
+
             response = self._client.chat.completions.create(
                 messages=messages,
                 model=model,
