@@ -1,6 +1,4 @@
-from betterproto import Casing
-
-from maitai_gen.config import Config, InferenceLocations
+from maitai.models.config import Config, InferenceLocations
 
 
 def get_default_config() -> Config:
@@ -22,12 +20,14 @@ def get_default_config() -> Config:
         context_retrieval_enabled=False,
         fallback_model=None,
         safe_mode=False,
+        extract_request_metadata=True,
+        metadata={},
     )
 
 
 def reconcile_config_with_default(config_dict: dict) -> Config:
-    default_config_json = get_default_config().to_pydict(casing=Casing.SNAKE)
+    default_config_json = get_default_config().model_dump()
     for key, value in default_config_json.items():
         if key not in config_dict:
             config_dict[key] = value
-    return Config().from_pydict(config_dict)
+    return Config.model_validate(config_dict)
