@@ -27,21 +27,28 @@ class IOThread(Thread):
     async def main_loop(self):
         await asyncio.sleep(self.interval)
         while self.run_thread:
-            await self.loop()
+            await self.process_loop()
 
-    async def loop(self):
+    async def process_loop(self):
         if self.run_thread:
             self.last_loop_start = time.time()
             self.is_running = True
             try:
                 self.process()
+                await self.process_async()
             except Exception as e:
-                self.print(e, f'[{self.child_name}] Exception hit processing', traceback.format_exc())
+                self.print(
+                    e,
+                    f"[{self.child_name}] Exception hit processing",
+                    traceback.format_exc(),
+                )
             finally:
                 self.is_running = False
 
             delta = time.time() - self.last_loop_start
-            self.avg_loop_time = ((self.avg_loop_time * self.completed_loops) * delta) / (self.completed_loops + 1)
+            self.avg_loop_time = (
+                (self.avg_loop_time * self.completed_loops) * delta
+            ) / (self.completed_loops + 1)
             self.completed_loops += 1
             next_run = self.interval - delta
             await asyncio.sleep(max(0, next_run))
@@ -51,11 +58,14 @@ class IOThread(Thread):
     def terminate(self):
         self.run_thread = False
         self.cleaned = True
-        self.print(f'{self.child_name} cleaned up')
+        self.print(f"{self.child_name} cleaned up")
 
     def process(self):
         return None
 
+    async def process_async(self):
+        return None
+
     def initialize(self):
         self.initialized = True
 
